@@ -19,140 +19,62 @@
 
 #include "handy.h"
 #include "utils.h"
-#include "fmh.h"
-
-#include <QDateTime>
 #include <QClipboard>
 #include <QDebug>
 #include <QIcon>
 #include <QMimeData>
 #include <QOperatingSystemVersion>
-#include <QStandardPaths>
-#include <QWindow>
-#include <QMouseEvent>
+#include <QTouchDevice>
 
 #include "platforms/platform.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QTouchDevice>
-#else
-#include <QInputDevice>
-#endif
-
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
 #else
 #include <QApplication>
 #endif
 
-#include <MauiMan/formfactormanager.h>
-#include <MauiMan/accessibilitymanager.h>
+#include "fmh.h"
 
-Handy *Handy::m_instance = nullptr;
+#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#include <KSharedConfig>
+#include <QFileSystemWatcher>
+#endif
+
+static const QUrl CONF_FILE = FMH::ConfigPath + "/kdeglobals";
+
+#ifdef KSHAREDCONFIG_H
+static const auto confCheck = [](QString key, QVariant defaultValue) -> QVariant {
+    auto kconf = KSharedConfig::openConfig("kdeglobals");
+    const auto group = kconf->group("KDE");
+    if (group.hasKey(key))
+        return group.readEntry(key, defaultValue);
+
+    return defaultValue;
+};
+#endif
 
 Handy::Handy(QObject *parent)
     : QObject(parent)
-    ,m_hasTransientTouchInput(false)
-    ,m_formFactor(new MauiMan::FormFactorManager(this))
-    ,m_accessibility(new MauiMan::AccessibilityManager(this))
+    , m_isTouch(Handy::isTouch())
 {
-    qDebug() << "CREATING INSTANCE OF MAUI HANDY";
-    
-    connect(m_accessibility, &MauiMan::AccessibilityManager::singleClickChanged, [&](bool value)
-    {
-        m_singleClick = value;
-        Q_EMIT singleClickChanged();
+#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+
+    auto configWatcher = new QFileSystemWatcher({CONF_FILE.toLocalFile()}, this);
+
+    m_singleClick = confCheck("SingleClick", m_singleClick).toBool();
+    emit singleClickChanged();
+
+    connect(configWatcher, &QFileSystemWatcher::fileChanged, [&](QString) {
+        m_singleClick = confCheck("SingleClick", m_singleClick).toBool();
+        emit singleClickChanged();
     });
-    
-    m_singleClick = m_accessibility->singleClick();   
-    
-// #ifdef FORMFACTOR_FOUND //TODO check here for Cask desktop enviroment
+#elif defined Q_OS_MAC || defined Q_OS_WIN32
 
-connect(m_formFactor, &MauiMan::FormFactorManager::preferredModeChanged, [this](uint value)
-{    
-   m_ffactor = static_cast<FFactor>(value);
-   m_mobile = m_ffactor == FFactor::Phone || m_ffactor == FFactor::Tablet;
-   Q_EMIT formFactorChanged();
-   Q_EMIT isMobileChanged();
-});
+    m_singleClick = false;
+    emit singleClickChanged();
 
-connect(m_formFactor, &MauiMan::FormFactorManager::hasTouchscreenChanged, [this](bool value)
-{    
-    m_isTouch = value;
-    Q_EMIT isTouchChanged();
-});
-
-m_ffactor = static_cast<FFactor>(m_formFactor->preferredMode());
-m_mobile = m_ffactor == FFactor::Phone || m_ffactor == FFactor::Tablet;
-m_isTouch = m_formFactor->hasTouchscreen();
-
-
-    connect(qApp, &QGuiApplication::focusWindowChanged, this, [this](QWindow *win) 
-    {
-        if (win) 
-        {
-            win->installEventFilter(this);
-        }
-    });
-
-
-connect(qApp, &QCoreApplication::aboutToQuit, []()
-{
-    qDebug() << "Lets remove Handy singleton instance";
-    delete m_instance;
-    m_instance = nullptr;
-});
-}
-
-bool Handy::isTouch()
-{
-    return m_isTouch;
-}
-
-Handy::FFactor Handy::formFactor()
-{
-    return m_ffactor;
-}
-
-bool Handy::hasTransientTouchInput() const
-{
-    return m_hasTransientTouchInput;
-}
-
-void Handy::setTransientTouchInput(bool touch)
-{
-    if (touch == m_hasTransientTouchInput) {
-        return;
-    }
-    
-    m_hasTransientTouchInput = touch;
-     Q_EMIT hasTransientTouchInputChanged();    
-}
-
-bool Handy::eventFilter(QObject *watched, QEvent *event)
-{
-    Q_UNUSED(watched)
-    switch (event->type()) 
-    {
-        case QEvent::TouchBegin:
-            setTransientTouchInput(true);
-            break;
-        case QEvent::MouseButtonPress:
-        case QEvent::MouseMove: {
-            QMouseEvent *me = static_cast<QMouseEvent *>(event);
-            if (me->source() == Qt::MouseEventNotSynthesized) 
-            {
-                setTransientTouchInput(false);
-            }
-            break;
-        }
-        case QEvent::Wheel:
-            setTransientTouchInput(false);
-        default:
-            break;
-    }
-    
-    return false;
+#endif
 }
 
 #ifdef Q_OS_ANDROID
@@ -185,14 +107,14 @@ QVariantMap Handy::userInfo()
 QString Handy::getClipboardText()
 {
 #ifdef Q_OS_ANDROID
-    auto clipboard = QGuiApplication::clipboard();
+    auto clipbopard = QGuiApplication::clipboard();
 #else
-    auto clipboard = QApplication::clipboard();
+    auto clipbopard = QApplication::clipboard();
 #endif
 
-    auto mime = clipboard->mimeData();
+    auto mime = clipbopard->mimeData();
     if (mime->hasText())
-        return clipboard->text();
+        return clipbopard->text();
 
     return QString();
 }
@@ -286,14 +208,26 @@ bool Handy::isIOS()
     return FMH::isIOS();
 }
 
+bool Handy::isTouch()
+{
+    const auto devices = QTouchDevice::devices();
+    for (const auto &device : devices) {
+        if (device->type() == QTouchDevice::TouchScreen)
+            return true;
+        qDebug() << "DEVICE CAPABILITIES" << device->capabilities() << device->name();
+    }
+
+    return false;
+}
+
 bool Handy::hasKeyboard()
 {
-    return m_formFactor->hasKeyboard();
+    return Platform::instance()->hasKeyboard();
 }
 
 bool Handy::hasMouse()
 {
-    return m_formFactor->hasMouse();
+    return Platform::instance()->hasMouse();
 }
 
 bool Handy::isWindows()
@@ -305,50 +239,3 @@ bool Handy::isMac()
 {
     return FMH::isMac();
 }
-
-
-QString Handy::formatSize(quint64 size)
-{
-    const QLocale locale;
-    return locale.formattedDataSize(size);
-}
-
-QString Handy::formatDate(const QString &dateStr, const QString &format, const QString &initFormat)
-{
-    if (initFormat.isEmpty())
-        return QDateTime::fromString(dateStr, Qt::TextDate).toString(format);
-    else
-        return QDateTime::fromString(dateStr, initFormat).toString(format);
-}
-
-QString Handy::formatTime(const qint64 &value)
-{
-    QString tStr;
-    if (value) {
-        QTime time((value / 3600) % 60, (value / 60) % 60, value % 60, (value * 1000) % 1000);
-        QString format = "mm:ss";
-        if (value > 3600)
-        {
-            format = "hh:mm:ss";
-        }
-        tStr = time.toString(format);
-    }
-    
-    return tStr.isEmpty() ? "00:00" : tStr;
-}
-
-
-void Handy::saveSettings(const QString &key, const QVariant &value, const QString &group)
-{
-    UTIL::saveSettings(key, value, group);
-}
-
-QVariant Handy::loadSettings(const QString &key, const QString &group, const QVariant &defaultValue)
-{
-    return UTIL::loadSettings(key, group, defaultValue);
-}
-
-bool Handy::isMobile() const
-{
-    return m_mobile;
-}
